const express = require('express');

module.exports = {
    name: 'http-server',
    module: function(app, config) {
        const logger = app.logging.forModule('StatusListener');
        const status = app['status-listener'];

        const webserver = express();
        let httpServer;

        webserver.use((req, res, next) => {
            res.set({
                'Access-Control-Allow-Origin': '*',
                'Content-Type': 'application/json'
            });

            next();
        });
    
        webserver.get('/status', (req, res) => {
            status.current().then(status => res.status(200).send(JSON.stringify(status, null, 4)));
        });

        return {
            priority: 2,
            start: () => new Promise((resolve, reject) => {
                logger.logInfo('HTTP Server module starting');

                httpServer = webserver.listen(config.port, (err) => {
                    if(err) {
                        logger.logError(`Could not start HTTP Server`);
                        reject(err);
                    }

                    logger.logInfo(`HTTP Server started`, { port: config.port });

                    resolve();
                });
            }),
            stop: () => {}
        };
    }
};
